---
title: '[릴리즈노트] 2024-07-30 업데이트'
category: 업데이트
tags:
  - 업데이트
  - 파트너정산
searchTags:
  - 정산 상세 조회
  - 파트너 관리
  - 파트너 정산
datetime: 2024-11-04T06:49:52.174Z
---

<Callout title="2024년 7월 30일 파트너 정산 자동화 업데이트 소식을 안내드립니다." />



<Callout content="안녕하세요. 파트너 정산 자동화팀입니다.
24년 07월 30일, 서비스 개선 사항 안내드립니다.
파트너 정산내역에 관한 사용자 정의 속성을 등록/관리할 수 있는 기능이 출시되었습니다." />

## **주요 업데이트 사항**

✔️ 파트너 사용자 정의 속성



- 파트너 관리 페이지에서 파트너 사용자 정의 속성을 등록할 수 있으며 최대 10개까지 추가 가능합니다.
- 속성 이름은 등록 후에도 수정 가능합니다.
- 보안에 민감한 정보도 관리할 수 있도록 각각의 속성 값의 조회 권한을 설정할 수 있습니다.
- 등록된 값은 \[파트너 관리] 페이지와 \[정산 상세 조회] 페이지에서 확인 가능합니다.



- 파트너 정보 등록 / 파트너 정보 수정 시 속성 값을 지정할 수 있습니다.

✔️ 정산 사용자 정의 속성



- 정산 상세 조회 페이지에서 정산 사용자 정의 속성을 등록할 수 있으며 최대 10개까지 추가 가능합니다.
- 속성 이름은 등록 후에도 수정 가능합니다.
- 보안에 민감한 정보도 관리할 수 있도록 각 속성 값의 조회 권한을 설정할 수 있습니다.



- 파트너 사용자 정의 속성값과 정산 사용자 정의 속성 값은 \[정산 상세 조회] 페이지에서 확인할 수 있습니다.
- 관리자만 조회 가능할 수 있는 속성 칼럼은 비관리자가 조회 시 노출되지 않습니다.

##### [\[파트너정산 릴리즈노트\] 2024-07-30 업데이트 보러가기↗](https://developers.portone.io/release-notes/platform/2024-07-30)
